@@ -43,7 +43,7 @@ Run 'colima template' to set the default configurations or 'colima start --edit'
 		"  colima start --arch aarch64\n" +
 		"  colima start --dns 1.1.1.1 --dns 8.8.8.8\n" +
 		"  colima start --dns-host example.com=1.2.3.4\n" +
-		"  colima start --kubernetes --kubernetes-disable=coredns,servicelb,traefik,local-storage,metrics-server",
+		"  colima start --kubernetes --k3s-arg=--disable=coredns,servicelb,traefik,local-storage,metrics-server",
 	Args: cobra.MaximumNArgs(1),
 	RunE: func(cmd *cobra.Command, args []string) error {
 		app := newApp()
@@ -155,8 +155,11 @@ func init() {
 	startCmd.Flags().BoolVarP(&startCmdArgs.Flags.Foreground, "foreground", "f", false, "Keep colima in the foreground")
 	startCmd.Flags().StringVar(&startCmdArgs.Hostname, "hostname", "", "custom hostname for the virtual machine")
 
+	// host IP addresses
+	startCmd.Flags().BoolVar(&startCmdArgs.Network.HostAddresses, "network-host-addresses", false, "support port forwarding to specific host IP addresses")
+
 	if util.MacOS() {
-		// network
+		// network address
 		startCmd.Flags().BoolVar(&startCmdArgs.Network.Address, "network-address", false, "assign reachable IP address to the VM")
 
 		// vm type
@@ -168,7 +171,7 @@ func init() {
 		}
 
 		// nested virtualization
-		if util.M3() && util.MacOS15OrNewer() {
+		if util.MacOSNestedVirtualizationSupported() {
 			startCmd.Flags().BoolVarP(&startCmdArgs.NestedVirtualization, "nested-virtualization", "z", false, "enable nested virtualization")
 			startCmd.Flag("nested-virtualization").Hidden = true
 		}
@@ -437,6 +440,9 @@ func prepareConfig(cmd *cobra.Command) {
 			startCmdArgs.ActivateRuntime = current.ActivateRuntime
 		}
 	}
+	if !cmd.Flag("network-host-addresses").Changed {
+		startCmdArgs.Network.HostAddresses = current.Network.HostAddresses
+	}
 	if util.MacOS() {
 		if !cmd.Flag("network-address").Changed {
 			startCmdArgs.Network.Address = current.Network.Address
@@ -451,7 +457,7 @@ func prepareConfig(cmd *cobra.Command) {
 				startCmdArgs.VZRosetta = current.VZRosetta
 			}
 		}
-		if util.MacOS15OrNewer() {
+		if util.MacOSNestedVirtualizationSupported() {
 			if !cmd.Flag("nested-virtualization").Changed {
 				startCmdArgs.NestedVirtualization = current.NestedVirtualization
 			}
